@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,10 +38,11 @@ Q_SIGNALS:
     void loadFinished(bool success);
 
 private:
+    Q_DISABLE_COPY(SieveEditorLoadProgressIndicator)
     void slotTimerDone();
     int mProgressCount;
     KPixmapSequence mProgressPix;
-    QTimer *mProgressTimer;
+    QTimer *mProgressTimer = nullptr;
 };
 }
 
